==> darwin-shared-0.1.14.tar.gz: darwin-shared-0.1.14/darwin/models/model.py <==
from google.appengine.ext import ndb


class Model(ndb.Model):

    def id(self):
        return str(self.key.id())

    def keyString(self):
        return self.key.urlsafe()

    def delete(self):
        return self.key.delete()

    def parentKey(self):
        return self.key.parent()

    def save(self):
        return self.put()

    @classmethod
    def saveAll(cls, array):
        return ndb.put_multi(array)

    @classmethod
    def deleteAll(cls, array):
        if "count" in dir(array):
            if array.count() == 0: return
            return cls.deleteKeys([key for key in array.iter(keys_only=True)])
        return cls.deleteKeys([obj.key for obj in array])

    @classmethod
    def deleteKeys(cls, keys):
        return ndb.delete_multi(keys)

    @classmethod
    def getById(cls, id, parentKey=None):
        try:
            key = ndb.Key(cls, long(id) if str(id).isdigit() else id, parent=parentKey)
            obj = key.get()
        except:
            return None

        return obj if key and key.kind() == cls.__name__ else None

    @classmethod
    def getByIds(cls, ids, parentKey=None):
        return ndb.get_multi([ndb.Key(cls, long(id) if str(id).isdigit() else id, parent=parentKey) for id in ids])

    @classmethod
    def getByKey(cls, keyString):
        try:
            key = ndb.Key(urlsafe=keyString)
            obj = key.get()
        except:
            return None

        return obj if key and key.kind() == cls.__name__ else None

    @classmethod
    def getByKeys(cls, keys):
        return ndb.get_multi([ndb.Key(urlsafe=keyString) for keyString in keys])

==> darwin-shared-0.2.21.tar.gz: darwin-shared-0.2.21/darwin/models/model.py <==
from google.appengine.ext import ndb


class Model(ndb.Model):

    def id(self):
        return str(self.key.id())

    def keyString(self):
        return self.key.urlsafe()

    def delete(self):
        return self.key.delete()

    def parentKey(self):
        return self.key.parent()

    def save(self):
        return self.put()

    @classmethod
    def saveAll(cls, array):
        return ndb.put_multi(array)

    @classmethod
    def deleteAll(cls, array):
        if "count" in dir(array):
            if array.count() == 0: return
            return cls.deleteKeys([key for key in array.iter(keys_only=True)])
        return cls.deleteKeys([obj.key for obj in array])

    @classmethod
    def deleteKeys(cls, keys):
        return ndb.delete_multi(keys)

    @classmethod
    def getById(cls, id, parentKey=None, useCache=True):
        try:
            key = ndb.Key(cls, long(id) if str(id).isdigit() else id, parent=parentKey)
            obj = key.get(use_cache=useCache, use_memcache=useCache)
        except:
            return None

        return obj if key and key.kind() == cls.__name__ else None

    @classmethod
    def getByIds(cls, ids, parentKey=None):
        return ndb.get_multi([ndb.Key(cls, long(id) if str(id).isdigit() else id, parent=parentKey) for id in ids if id])

    @classmethod
    def getByKey(cls, keyString):
        try:
            key = ndb.Key(urlsafe=keyString)
            obj = key.get()
        except:
            return None

        return obj if key and key.kind() == cls.__name__ else None

    @classmethod
    def getByKeys(cls, keys):
        return ndb.get_multi([ndb.Key(urlsafe=keyString) for keyString in keys])
